==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/BiomeInit.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.Touhou;
import cc.thonly.reverie_dreams.world.gen.biome.DreamBiomeCreator;
import cc.thonly.reverie_dreams.world.gen.biome.TheMoonBiomeCreator;
import net.minecraft.class_1959;
import net.minecraft.class_2922;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_6796;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;


public class BiomeInit {
    public static final class_5321<class_1959> THE_MOON = getOrCreateRegistryKey("the_moon");
    public static final class_5321<class_1959> DREAM = getOrCreateRegistryKey("dream");

    public static void init() {

    }

    public static void bootstrap(class_7891<class_1959> context) {
        class_7871<class_6796> placedFeatureLookup = context.method_46799(class_7924.field_41245);
        class_7871<class_2922<?>> configuredCarverLookup = context.method_46799(class_7924.field_41238);
        context.method_46838(DREAM, DreamBiomeCreator.createDream(
                placedFeatureLookup, configuredCarverLookup
        ));
        context.method_46838(THE_MOON, TheMoonBiomeCreator.createTheMoon(
                placedFeatureLookup, configuredCarverLookup
        ));
    }

    public static class_5321<class_1959> getOrCreateRegistryKey(String name) {
        return getOrCreateRegistryKey(Touhou.id(name));
    }

    public static class_5321<class_1959> getOrCreateRegistryKey(class_2960 id) {
        return class_5321.method_29179(class_7924.field_41236, id);
    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/BiomeInit.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.world.gen.biome.DreamBiomeCreator;
import cc.thonly.reverie_dreams.world.gen.biome.TheMoonBiomeCreator;
import net.minecraft.class_1959;
import net.minecraft.class_2922;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_6796;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;


public class BiomeInit {
    public static final class_5321<class_1959> THE_MOON = getOrCreateRegistryKey("the_moon");
    public static final class_5321<class_1959> DREAM = getOrCreateRegistryKey("dream");

    public static void init() {

    }

    public static void bootstrap(class_7891<class_1959> context) {
        class_7871<class_6796> placedFeatureLookup = context.method_46799(class_7924.field_41245);
        class_7871<class_2922<?>> configuredCarverLookup = context.method_46799(class_7924.field_41238);
        context.method_46838(DREAM, DreamBiomeCreator.createDream(
                placedFeatureLookup, configuredCarverLookup
        ));
        context.method_46838(THE_MOON, TheMoonBiomeCreator.createTheMoon(
                placedFeatureLookup, configuredCarverLookup
        ));
    }

    public static class_5321<class_1959> getOrCreateRegistryKey(String name) {
        return getOrCreateRegistryKey(ReverieDreams.id(name));
    }

    public static class_5321<class_1959> getOrCreateRegistryKey(class_2960 id) {
        return class_5321.method_29179(class_7924.field_41236, id);
    }

}
